/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.doubleclickbidmanager.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * Represents a query.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the DoubleClick Bid Manager API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Query extends GenericJson {

  /**
   * The kind, fixed to "doubleclickbidmanager#query".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Query metadata.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private QueryMetadata metadata;

  /**
   * Query parameters.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Parameters params;

  /**
   * Query ID.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long queryId;

  /**
   * The ending time for the data that is shown in the report. Note, reportDataEndTimeMs is required
   * if metadata.dataRange is CUSTOM_DATES and ignored otherwise.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long reportDataEndTimeMs;

  /**
   * The starting time for the data that is shown in the report. Note, reportDataStartTimeMs is
   * required if metadata.dataRange is CUSTOM_DATES and ignored otherwise.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long reportDataStartTimeMs;

  /**
   * Information on how often and when to run a query.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private QuerySchedule schedule;

  /**
   * Canonical timezone code for report data time. Defaults to America/New_York.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String timezoneCode;

  /**
   * The kind, fixed to "doubleclickbidmanager#query".
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind, fixed to "doubleclickbidmanager#query".
   * The value set may be {@code null}.
   */
  public Query setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Query metadata.
   * The value returned may be {@code null}.
   */
  public QueryMetadata getMetadata() {
    return metadata;
  }

  /**
   * Query metadata.
   * The value set may be {@code null}.
   */
  public Query setMetadata(QueryMetadata metadata) {
    this.metadata = metadata;
    return this;
  }

  /**
   * Query parameters.
   * The value returned may be {@code null}.
   */
  public Parameters getParams() {
    return params;
  }

  /**
   * Query parameters.
   * The value set may be {@code null}.
   */
  public Query setParams(Parameters params) {
    this.params = params;
    return this;
  }

  /**
   * Query ID.
   * The value returned may be {@code null}.
   */
  public Long getQueryId() {
    return queryId;
  }

  /**
   * Query ID.
   * The value set may be {@code null}.
   */
  public Query setQueryId(Long queryId) {
    this.queryId = queryId;
    return this;
  }

  /**
   * The ending time for the data that is shown in the report. Note, reportDataEndTimeMs is required
   * if metadata.dataRange is CUSTOM_DATES and ignored otherwise.
   * The value returned may be {@code null}.
   */
  public Long getReportDataEndTimeMs() {
    return reportDataEndTimeMs;
  }

  /**
   * The ending time for the data that is shown in the report. Note, reportDataEndTimeMs is required
   * if metadata.dataRange is CUSTOM_DATES and ignored otherwise.
   * The value set may be {@code null}.
   */
  public Query setReportDataEndTimeMs(Long reportDataEndTimeMs) {
    this.reportDataEndTimeMs = reportDataEndTimeMs;
    return this;
  }

  /**
   * The starting time for the data that is shown in the report. Note, reportDataStartTimeMs is
   * required if metadata.dataRange is CUSTOM_DATES and ignored otherwise.
   * The value returned may be {@code null}.
   */
  public Long getReportDataStartTimeMs() {
    return reportDataStartTimeMs;
  }

  /**
   * The starting time for the data that is shown in the report. Note, reportDataStartTimeMs is
   * required if metadata.dataRange is CUSTOM_DATES and ignored otherwise.
   * The value set may be {@code null}.
   */
  public Query setReportDataStartTimeMs(Long reportDataStartTimeMs) {
    this.reportDataStartTimeMs = reportDataStartTimeMs;
    return this;
  }

  /**
   * Information on how often and when to run a query.
   * The value returned may be {@code null}.
   */
  public QuerySchedule getSchedule() {
    return schedule;
  }

  /**
   * Information on how often and when to run a query.
   * The value set may be {@code null}.
   */
  public Query setSchedule(QuerySchedule schedule) {
    this.schedule = schedule;
    return this;
  }

  /**
   * Canonical timezone code for report data time. Defaults to America/New_York.
   * The value returned may be {@code null}.
   */
  public String getTimezoneCode() {
    return timezoneCode;
  }

  /**
   * Canonical timezone code for report data time. Defaults to America/New_York.
   * The value set may be {@code null}.
   */
  public Query setTimezoneCode(String timezoneCode) {
    this.timezoneCode = timezoneCode;
    return this;
  }

}
